# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,synth_result)
S3method(as.list,synth_linked_result)
S3method(plot,flexsynth_diagnostics)
S3method(print,dp_accounting)
S3method(print,dp_control)
S3method(print,flexsynth_diagnostics)
S3method(print,flexsynth_diagnostics_list)
S3method(print,flexsynth_disclosure)
S3method(print,flexsynth_disclosure_list)
S3method(print,flexsynth_pool)
S3method(print,flexsynth_rule)
S3method(print,flexsynth_utility)
S3method(print,synth_control)
S3method(print,synth_linked_result)
S3method(print,synth_result)
export(check_linkage)
export(compare_estimates)
export(diagnose)
export(disclosure_risk)
export(dp_control)
export(list_methods)
export(pool_synth)
export(register_method)
export(rule)
export(synth)
export(synth_control)
export(synth_glm)
export(synth_linked)
importFrom(stats,ave)
importFrom(stats,predict)
importFrom(stats,setNames)
importFrom(utils,modifyList)
